# 8. Change Log

[Fabric GitHub][fabricGithubLink]

[MCP][MCP]

| Version | Date       | Author        | Description of Changes                                                                                                                               |
| :------ | :--------- | :------------ | :--------------------------------------------------------------------------------------------------------------------------------------------------- |
| 1.0.1   | 2025-05-27 | Kayvan Sylvan  | Format fixes. Table of Contents. |
| 1.0.0   | 2025-05-27 | BMad (as PM)  | Initial PRD draft completed for MVP. Epics 1-4 defined. Transports: stdio, Streamable HTTP, SSE. Key redaction for config. Dev env updates included. |

[fabricGithubLink]: https://github.com/danielmiessler/fabric
[MCP]: https://modelcontextprotocol.io/
